Modules
- test
- Session test runner (
lxdev test). Runtime-owned: the dev server forwards these to the host, which executes the bundled test in an isolatedlingxia-automationruntime.
Constants
- SHUTDOWN
- Request the owning
lingxia devprocess to stop this session. Handled by the dev server, not forwarded to the runtime.